==> PySpice-0.3.2.tar.gz: PySpice-0.3.2/setup.py <==
#! /usr/bin/env python

####################################################################################################
#
# PySpice - A Spice package for Python
# Copyright (C) 2014 Salvaire Fabrice
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
####################################################################################################

####################################################################################################

import sys

from distutils.core import setup
# from setuptools import setup

####################################################################################################

if sys.version_info < (3,):
    print('PySpice requires Python 3', file=sys.stderr)
    sys.exit(1)
if sys.version_info < (3,4):
    print('WARNING: PySpice could require Python 3.4 ...', file=sys.stderr)

exec(compile(open('setup_data.py').read(), 'setup_data.py', 'exec'))

setup(**setup_dict)

####################################################################################################
#
# End
#
####################################################################################################

==> PySpice-1.5.tar.gz: PySpice-1.5/setup.py <==
#! /usr/bin/env python3

####################################################################################################
#
# PySpice - A Spice package for Python
# Copyright (C) 2017 Fabrice Salvaire
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
####################################################################################################

####################################################################################################

import sys

from setuptools import setup

####################################################################################################

# Check for python3 setup.py install
required_python_version = (3, 6)
if sys.version_info < required_python_version:
    sys.stderr.write('ERROR: PySpice requires Python {}.{}\n'.format(*required_python_version))
    sys.exit(1)

####################################################################################################

# Fixme: could check for ngspice, Xyce, libngspice.so etc.

# check a simulator is installed
# try:
#     rc = subprocess.check_call(('ngspice', '--version'), stdout=sys.stderr)
# except FileNotFoundError:
#     sys.stderr.write('\n\nWarning: You must install ngspice\n\n')

####################################################################################################

from setup_data import setup_dict
setup(**setup_dict)
